@@ -13,19 +13,19 @@ import org.gnu.glib.Handle;
 import org.gnu.pango.Attribute;
 
 /**
- *
+ * 
  */
-public class PangoAttrEmbossed extends Attribute
-{
-    public PangoAttrEmbossed( boolean embossed ) {
-        super( gdk_pango_attr_embossed_new( embossed ) );
+public class PangoAttrEmbossed extends Attribute {
+    public PangoAttrEmbossed(boolean embossed) {
+        super(gdk_pango_attr_embossed_new(embossed));
     }
 
     public boolean getEmbossed() {
-        return getEmbossed( getHandle() );
+        return getEmbossed(getHandle());
     }
 
-    native static final protected boolean getEmbossed (Handle obj);
-    native static final protected Handle gdk_pango_attr_embossed_new (boolean embossed);
-}
+    native static final protected boolean getEmbossed(Handle obj);
 
+    native static final protected Handle gdk_pango_attr_embossed_new(
+            boolean embossed);
+}
