@@ -12,15 +12,16 @@ package org.gnu.gtk;
 /**
  */
 public class FileChooserException extends Exception {
-	private int errorCode = 0;
-	
-	FileChooserException(int errorCode) {
-		this.errorCode = errorCode;
-	}
-	
-	private FileChooserException() {}
-	
-	public FileChooserError getError() {
-		return FileChooserError.intern(errorCode);
-	}
+    private int errorCode = 0;
+
+    FileChooserException(int errorCode) {
+        this.errorCode = errorCode;
+    }
+
+    private FileChooserException() {
+    }
+
+    public FileChooserError getError() {
+        return FileChooserError.intern(errorCode);
+    }
 }
