@@ -395,6 +395,35 @@ public class ListStore extends TreeModel implements TreeSortable,
                 .getColumn(), val.getHandle());
     }
 
+    /**
+     * Sets a value in the dataStore. The type of the value <em>must</em>
+     * match the type set for that dataBlock in the constructor.
+     * <p>
+     * This does not make the data visible in any of the widgets which use the
+     * class - to do that, you have to construct a {@link TreeViewColumn} and
+     * add it to the {@link TreeView}; construct and add a {@link CellRenderer}
+     * to that; and finally associate the properties of the CellRenderer with
+     * the dataBlocks, using the
+     * {@link TreeViewColumn#addAttributeMapping(CellRenderer, CellRendererAttribute,
+     * DataColumn)} method.
+     * 
+     * @param dataBlock
+     *            The datablock in which the data should be stored.
+     * @param iter
+     *            Valid iterator for the data row in which the value is to be
+     *            set. These can be gotten using methods such as
+     *            {@link #appendRow(TreeIter)}.
+     * @param value
+     *            The <code>long</code> value to set into this row.
+     * @since 2.8.5
+     */
+    public void setValue(TreeIter iter, DataColumnLong dataBlock, long value) {
+        Value val = new Value(Type.LONG());
+        val.setLong(value);
+        gtk_list_store_set_value(getHandle(), iter.getHandle(), dataBlock
+                .getColumn(), val.getHandle());
+    }
+
     /**
      * Sets a value in the data store. To display the data in the widget, you
      * need to associate the datablock with the renderer, using methods of the
@@ -699,6 +728,9 @@ public class ListStore extends TreeModel implements TreeSortable,
     }
 
     public boolean isIterValid(TreeIter iter) {
+        if (iter == null)
+            return false;
+
         return gtk_list_store_iter_is_valid(getHandle(), iter.getHandle());
     }
 
@@ -750,8 +782,8 @@ public class ListStore extends TreeModel implements TreeSortable,
     native static final protected void gtk_list_store_move_before(
             Handle listStore, Handle iter, Handle position);
 
-    native static protected void tree_sortable_set_sort_column_id(Handle sortable,
-            int col, int order);
+    native static protected void tree_sortable_set_sort_column_id(
+            Handle sortable, int col, int order);
 
     // native static final protected int getRoot (int cptr);
     // native final protected void setRoot (int cptr, int root);
