@@ -131,6 +131,19 @@ public class TreeModel extends GObject {
         return val.getInt();
     }
 
+    /**
+     * Returns the <code>long</code> at the row specified by iter and column
+     * specified data block.
+     * 
+     * @since 2.8.5
+     */
+    public long getValue(TreeIter iter, DataColumnLong dataBlock) {
+        Handle value = gtk_tree_model_get_value(getHandle(), iter.getHandle(),
+                dataBlock.getColumn());
+        Value val = new Value(value);
+        return val.getLong();
+    }
+
     /**
      * Returns the Value at the given iter in the specified data block.
      */
