@@ -18,18 +18,19 @@ import org.gnu.glib.EventType;
 import org.gnu.gtk.Widget;
 
 public class DragEvent extends GtkEvent {
-	private final DragContext context;
-	
-	public DragEvent(Widget source, EventType type, DragContext context) {
-		super(source, type);
-		this.context = context;
-	}
-	
-	protected DragEvent(DragEvent event) {
-		this((Widget) event.getSource(), event.getType(), event.getDragContext());
-	}
-	
-	public DragContext getDragContext() {
-		return context;
-	}
+    private final DragContext context;
+
+    public DragEvent(Widget source, EventType type, DragContext context) {
+        super(source, type);
+        this.context = context;
+    }
+
+    protected DragEvent(DragEvent event) {
+        this((Widget) event.getSource(), event.getType(), event
+                .getDragContext());
+    }
+
+    public DragContext getDragContext() {
+        return context;
+    }
 }
