@@ -16,31 +16,30 @@ package org.gnu.gtk.event;
 
 import org.gnu.glib.EventType;
 
-
 /**
  * An event represeting action by a {@link org.gnu.gtk.SpinButton} widget.
+ * 
  * @see SpinListener
  * @see org.gnu.gtk.SpinButton
  */
 public class SpinEvent extends GtkEvent {
 
-	public static class Type extends EventType {
-	    private Type(int id, String name){
-		super(id, name);
-	    }
+    public static class Type extends EventType {
+        private Type(int id, String name) {
+            super(id, name);
+        }
 
-	    /**
-	     * This event indicates that the menu item has been activated.
-	     */
-	    public static final Type VALUE_CHANGED = 
-		new Type(1, "VALUE_CHANGED");
-	}
+        /**
+         * This event indicates that the menu item has been activated.
+         */
+        public static final Type VALUE_CHANGED = new Type(1, "VALUE_CHANGED");
+    }
 
-	/**
-	 * Creates a new Spin Event. This is used internally by java-gnome. Users
-	 * only have to deal with listeners.
-	 */
-	public SpinEvent(Object source) {
-		super(source, Type.VALUE_CHANGED);
-	}
+    /**
+     * Creates a new Spin Event. This is used internally by java-gnome. Users
+     * only have to deal with listeners.
+     */
+    public SpinEvent(Object source) {
+        super(source, Type.VALUE_CHANGED);
+    }
 }
